@@ -15,18 +15,21 @@ dbern <- function(x, prob, log = FALSE)  {
 }
 
 #' @rdname bern
+#' @export
 pbern <- function(q, prob, lower.tail = TRUE, log = FALSE)  {
   stats::pbinom(q, size = 1, prob = prob, lower.tail = lower.tail,
-         log = log)
+         log.p = log)
 }
 
 #' @rdname bern
+#' @export
 qbern <- function(p, prob, lower.tail = TRUE, log = FALSE)  {
   stats::qbinom(p, size = 1, prob = prob, lower.tail = lower.tail,
-         log = log)
+         log.p = log)
 }
 
 #' @rdname bern
+#' @export
 rbern <- function(n, prob)  {
   stats::rbinom(n, size = 1, prob = prob)
 }
