@@ -2,10 +2,11 @@
 #'
 #' A Bayesian p-value (p) is here defined in terms of the quantile-based
 #' (1-p) * 100% credible interval (CRI) that
-#' just includes 0 (Kery and Schaub 2011).
-#' In other words a p-value of 0.05 indicates that the 95% CRI just includes 0.
+#' just includes a threshold (Kery and Schaub 2011).
+#' By default a p-value of 0.05 indicates that the 95% CRI just includes 0.
 #'
 #' @param x A numeric vector of MCMC values.
+#' @inheritParams params
 #' @return A number between 0 and 1.
 #' @family summary
 #' @references
@@ -15,16 +16,23 @@
 #' @export
 #' @examples
 #' pvalue(as.numeric(0:100))
-pvalue <- function(x) {
+pvalue <- function(x, threshold = 0, na_rm = FALSE) {
   chk_numeric(x)
+  chk_number(threshold)
+
+  if(anyNA(x)) {
+    if(vld_false(na_rm)) return(NA_real_)
+    x <- as.vector(x)
+    x <- x[!is.na(x)]
+  }
   if (!length(x)) {
     return(NA_real_)
   }
   n <- length(x)
-  s1 <- sum(x < 0)
-  s2 <- sum(x > 0)
+  s1 <- sum(x < threshold)
+  s2 <- sum(x > threshold)
   s <- min(s1, s2)
   s <- s * 2 # two sided p-value
-  s <- s + n - s1 - s2 # include 0 values
+  s <- s + n - s1 - s2 # include threshold values
   (s + 1) / (n + 1) # avoid pvalues of 0
 }
