@@ -3,7 +3,7 @@ test_that("zscore", {
   expect_identical(zscore(integer(0)), NA_real_)
   expect_equal(zscore(1), NA_real_)
   expect_equal(zscore(c(1, 1)), Inf)
-  expect_equal(zscore(c(0, 0)), NA_real_)
+  expect_equal(zscore(c(0, 0)), NaN)
   expect_equal(zscore(0), NA_real_)
   set.seed(101)
   expect_equal(zscore(rnorm(1000, 2)), 2.04891535423035)
